bl_info = {
    "name": "Align to 3D Cursor",
    "author": "Lino Grandi",
    "version": (1, 0),
    "blender": (3, 0, 0),
    "location": "View3D > Sidebar > Tool tab",
    "description": "Align selected objects to 3D Cursor (position and rotation)",
    "category": "Object",
}

import bpy

class OBJECT_OT_align_to_cursor(bpy.types.Operator):
    bl_idname = "object.align_to_cursor"
    bl_label = "Align to 3D Cursor"
    bl_description = "Align selected objects to the 3D Cursor (position and rotation)"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        cursor = context.scene.cursor
        selected_objects = context.selected_objects

        if not selected_objects:
            self.report({'WARNING'}, "No objects selected.")
            return {'CANCELLED'}

        for obj in selected_objects:
            if obj.type not in {'MESH', 'LIGHT', 'EMPTY', 'CURVE', 'SURFACE', 'FONT'}:
                continue  # Optional: limit object types

            obj.location = cursor.location.copy()
            obj.rotation_mode = 'XYZ'
            obj.rotation_euler = cursor.rotation_euler.copy()

        return {'FINISHED'}

class VIEW3D_PT_align_to_cursor_panel(bpy.types.Panel):
    bl_label = "Align to 3D Cursor"
    bl_idname = "VIEW3D_PT_align_to_cursor_panel"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = "Tool"

    def draw(self, context):
        layout = self.layout
        layout.operator("object.align_to_cursor", icon='PIVOT_CURSOR')

classes = (
    OBJECT_OT_align_to_cursor,
    VIEW3D_PT_align_to_cursor_panel,
)

def register():
    for cls in classes:
        bpy.utils.register_class(cls)

def unregister():
    for cls in reversed(classes):
        bpy.utils.unregister_class(cls)

if __name__ == "__main__":
    register()
